@@ -857,7 +857,7 @@ process_module_files_add_removable_media (TrackerProcessor *processor)
 		file = g_file_new_for_path (root);
 		tracker_monitor_add (processor->private->monitor, module_name, file);
 		g_object_unref (file);
-		
+
 		tracker_crawler_special_paths_add (crawler, root);
 
 		break;
@@ -1031,6 +1031,13 @@ process_module_next (TrackerProcessor *processor)
 	const gchar *module_name;
 	gboolean     is_removable_media;
 
+	if (tracker_status_get_is_readonly ()) {
+		/* Block any request to process
+		 * modules if indexing is not enabled
+		 */
+		return;
+	}
+
 	/* Don't recursively iterate the modules if this function is
 	 * called, check first.
 	 */
@@ -1784,6 +1791,10 @@ tracker_processor_stop (TrackerProcessor *processor)
 		processor->private->finished = TRUE;
 		g_signal_emit (processor, signals[FINISHED], 0);
 	} else {
+		/* Set status to IDLE, so it isn't left to any other state
+		 * if there are no files to be sent to the indexer.
+		 */
+		tracker_status_set_and_signal (TRACKER_STATUS_IDLE);
 		item_queue_handlers_set_up (processor);
 	}
 }
